Learn R Programming

mclcar (version 0.2-0)

mcl.HCAR: The Monte Carlo likelihood function of the HCAR model.

Description

Evaluate the Monte Carlo likelihood of a hierarchical conditional-autoregressive model at a given parameter value and importance sampler value.

Usage

mcl.HCAR(pars, mcdata, data, Evar = FALSE)

Arguments

pars

parameter values at which the Monte Carlo likelihood function to be evaluated

mcdata

The Monte Carlo sample object returned by the function sim.HCAR

data

A list or an environment containing the same variables same as the input for sim.HCAR,

Evar

If true, the Monte Carlo variance is evaluated.

Value

mc.lr

the Monte Carlo likelihood

v.lr

if Evar = TRUE, the Monte Carlo variance of the likelihood is also returned

See Also

sim.HCAR, OptimMCL.HCAR, summary.OptimMCL.HCAR