Learn R Programming

mclcar (version 0.2-0)

summary.OptimMCL.HCAR: Summary the output from the iterative procedure of maximising the Monte Carlo likelihood.

Description

The summary function summarizes the output of the output from the function OptimMCL.HCAR and the ranef.HCAR calculate the empirical Bayesian estimates of the random effects given the Monte Carlo maximum likelihood estimates.

Usage

# S3 method for OptimMCL.HCAR
summary(object, trace.all = TRUE, mc.covar =
  TRUE, ...)
  
ranef.HCAR(pars, data)

Arguments

object

an OptimMCL object returned by OptimMCL.HCAR.

trace.all

an logic value tells whether the input object given by OptimMCL.HCAR contains results from all iterations of not

mc.covar

if TRUE, the estimated covariance matrix of the MC-MLE is returned

...

arguments passed to or from other methods.

pars

the paramter values for calculating the empirical Bayesian estimates of the random effects; a list or enivironment of data for example same as described in sim.HCAR

data

A list or an environment contains the variables same as described in sim.HCAR.

Value

The summary function returns a list containing the following objects:

MC.mle,

the final MC-MLE

N.iter,

the total number of iterations

total.time,

the total time elapsed

convergence,

if TRUE the procedure converges

hessian,

the Hessian at the MC-MLE if given; the default is NULL

mc.covar

the estimated covariance matrix of the MC-MLE if given; the default is NULL

mc.samples

the Monte Carlo samples size used in the initial stage and after the first convergence.

The ranef.HCAR function return a dataframe object containing the estimated random effects and their corresponding standard deviations.

See Also

mcl.HCAR, sim.HCAR, OptimMCL.HCAR

Examples

Run this code
# NOT RUN {
## See examples for OptimMCL
# }

Run the code above in your browser using DataLab