Learn R Programming

mclcar (version 0.2-0)

summary.rsmMCL: Summary the output from the response surface method of maximising the Monte Carlo likelihood

Description

This function summarizes the output of the output from the function rsmMCL.

Usage

# S3 method for rsmMCL
summary(object, family, trace.all = TRUE, mc.covar =
TRUE, …)

Arguments

object

an rsmMCL object returned by rsmMCL.

family

a character takes value in "gauss", "binom" and "poisson".

trace.all

an logic value tells whether the input object given by rsmMCL contains results from all iterations of not

mc.covar

if TRUE, the estimated covariance matrix of the MC-MLE is returned

arguments passed to or from other methods.

Value

A list containing the following objects:

MC.mle,

the final MC-MLE

N.iter,

the total number of iterations

total.time,

the total time elapsed

convergence,

if TRUE the procedure converges

hessian,

the Hessian at the MC-MLE if given; the default is NULL

mc.covar

the estimated covariance matrix of the MC-MLE if given; the default is NULL

mc.samples

the Monte Carlo samples size used in the initial stage and after the first convergence.

See Also

rsmMCL

Examples

Run this code
# NOT RUN {
## See examples for rsmMCL
# }

Run the code above in your browser using DataLab