Evaluate the Monte Carlo likelihood of a hierarchical conditional-autoregressive model at a given parameter value and importance sampler value.
mcl.HCAR(pars, mcdata, data, Evar = FALSE)parameter values at which the Monte Carlo likelihood function to be evaluated
The Monte Carlo sample object returned by the function sim.HCAR
A list or an environment containing the same variables same as the input for sim.HCAR,
If true, the Monte Carlo variance is evaluated.
the Monte Carlo likelihood
if Evar = TRUE, the Monte Carlo variance of the likelihood is also returned