The summary function summarizes the output of the output from the
function OptimMCL.HCAR and the ranef.HCAR calculate the empirical Bayesian estimates of the random effects given the Monte Carlo maximum likelihood estimates.
# S3 method for OptimMCL.HCAR
summary(object, trace.all = TRUE, mc.covar =
TRUE, ...)
ranef.HCAR(pars, data)an OptimMCL object returned by OptimMCL.HCAR.
an logic value tells whether the input object given
by OptimMCL.HCAR contains results from all iterations of not
if TRUE, the estimated covariance matrix of the MC-MLE is returned
arguments passed to or from other methods.
the paramter values for calculating the empirical Bayesian estimates of the random effects; a list or enivironment of data for example same as described in sim.HCAR
A list or an environment contains the variables same as described in sim.HCAR.
The summary function returns a list containing the following objects:
the final MC-MLE
the total number of iterations
the total time elapsed
if TRUE the procedure converges
the Hessian at the MC-MLE if given; the default is NULL
the estimated covariance matrix of the MC-MLE if given; the default is NULL
the Monte Carlo samples size used in the initial stage and after the first convergence.
The ranef.HCAR function return a dataframe object containing the estimated random effects and their corresponding standard deviations.
# NOT RUN {
## See examples for OptimMCL
# }
Run the code above in your browser using DataLab